@@ -1,5 +1,6 @@
-# $Id: Size.pm,v 1.5 2004/09/08 01:36:02 comdog Exp $
+# $Id: Size.pm,v 1.7 2006/03/21 19:21:22 comdog Exp $
 package HTTP::Size;
+use strict;
 
 =head1 NAME
 
@@ -15,15 +16,15 @@ HTTP::Size - Get the byte size of an internet resource
 		{
 		print "$url size was $size";
 		}
-	elsif( HTTP::Size::ERROR == $HTTP::Size::INVALID_URL )
+	elsif( $HTTP::Size::ERROR == $HTTP::Size::INVALID_URL )
 		{
 		print "$url is not a valid absolute URL";
 		}
-	elsif( HTTP::Size::ERROR == $HTTP::Size::COULD_NOT_FETCH )
+	elsif( $HTTP::Size::ERROR == $HTTP::Size::COULD_NOT_FETCH )
 		{
 		print "Could not fetch $url\nHTTP status is $HTTP::Size::HTTP_STATUS";
 		}
-	elsif( HTTP::Size::ERROR == $HTTP::Size::BAD_CONTENT_LENGTH )
+	elsif( $HTTP::Size::ERROR == $HTTP::Size::BAD_CONTENT_LENGTH )
 		{
 		print "Could not determine content length of $url";
 		}
@@ -53,14 +54,15 @@ package.
 use subs qw( get_size _request );
 use vars qw(
 	$ERROR $HTTP_STATUS $VERSION
-	$INVALID_URL $COULD_NOT_FETCH $BAD_CONTENT_TYPE
+	$INVALID_URL $COULD_NOT_FETCH $BAD_CONTENT_LENGTH
+	$CONTENT $CONTENT_TYPE
 	);
 
 use LWP::UserAgent;
 use URI;
 use HTTP::Request;
 
-$VERSION = 0.91;
+$VERSION = 0.92;
 
 my $User_agent = LWP::UserAgent->new();
 
@@ -122,7 +124,7 @@ sub get_size
 
 	unless( not $method and $response->is_success and $size )
 		{
-		$request     = HTTP::Request->new( GET => $url->as_string );
+		my $request  = HTTP::Request->new( GET => $url->as_string );
 		$response    = _request( $request );
 		$HTTP_STATUS = $response->code;
 		$CONTENT     = $response->content;
@@ -264,7 +266,7 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2000-2004, brian d foy, All Rights Reserved.
+Copyright (c) 2000-2006, brian d foy, All Rights Reserved.
 
 You may redistribute this under the same terms as Perl itself.
 
